.. MicroStructPy documentation master file.

.. include:: ../../README.rst
    :end-before: end-badges

.. include:: welcome.rst
    :start-after: index-start

.. toctree::
   :hidden:
   :maxdepth: 2

   getting_started
   examples/index
   cli/index
   package_guide
   file_formats
   api/index
   troubleshooting
   changelog


.. external images and shields

.. include:: ../../README.rst
    :start-after: external-images
